import { useEffect, useState } from "react"

export default (onClick: (e: MouseEvent) => void) => {
	const [el, setEl] = useState<HTMLElement | null>(null)

    useEffect(() => {
        if (!el) return

        let mouseDownX = 0
        let mouseDownY = 0
        let mouseDownTime = 0

        const handleMouseDown = (e: MouseEvent) => {
            mouseDownX = e.clientX
            mouseDownY = e.clientY
            mouseDownTime = Date.now()
        }
        el.addEventListener("mousedown", handleMouseDown)
        
        const handleClick = (e: MouseEvent) => {
            const xDiff = Math.abs(e.clientX - mouseDownX)
            const yDiff = Math.abs(e.clientY - mouseDownY)
            const timeDiff = Date.now() - mouseDownTime
            if (xDiff > 10 || yDiff > 10 || timeDiff > 250) {
                e.preventDefault()
                e.stopPropagation()
                return
            }
            onClick(e)
        }
        el.addEventListener("click", handleClick)

        return () => {
            el.removeEventListener("mousedown", handleMouseDown)
            el.removeEventListener("click", handleClick)
        }
    }, [el])

    return setEl
}